@@ -1111,7 +1111,7 @@ impl SelectStatement {
     /// );
     /// ```
     pub fn cond_having(&mut self, condition: Condition) -> &mut Self {
-        self.having.set_where(condition);
+        self.having.add_condition(condition);
         self
     }
 
@@ -1291,8 +1291,8 @@ impl ConditionalStatement for SelectStatement {
         self
     }
 
-    fn cond_where(&mut self, condition: Condition) -> &mut Self {
-        self.wherei.set_where(condition);
+    fn cond_where<C>(&mut self, condition: C) -> &mut Self where C: IntoCondition {
+        self.wherei.add_condition(condition.into_condition());
         self
     }
 }
